@@ -7,14 +7,13 @@ resources and information with each other easly.
 isort: skip_file
 """
 
-from spade.message import Message
-from spade.template import Template
-
 from peak.core import *
+from peak.message import *
+from peak.template import *
 from peak.agents import *
 from peak.behaviours import *
 from peak.logging import *
 
 __author__ = "GECAD"
 __email__ = "brgri@isep.ipp.pt"
-__version__ = "1.0.16"
+__version__ = "1.2.4"
